Get a tidy data frame of available EPC data files
Source:R/odc_bulk_download.R
odc_get_file_list.RdRetrieve a clean data frame with file names and sizes. This provides a convenient overview of all downloadable Energy Performance Certificate data files.